@@ -5,14 +5,16 @@ Python supplemental features
 ----------------------------
 
 python_plus adds various features to python 2 and python 3 programs.
-It is designed to be used as integration of pypi future to help to port your code from Python 2 to Python 3 and still have it run on Python 2.
+It is designed to be used as integration of pypi future to help to port your code
+from Python 2 to Python 3 and still have it run on Python 2.
 
 
 vem: virtual environment manager
 ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 
 This package is released with an nice command:
-**vem** that is an interactive tool with some nice features to manage standard virtual environment and it is osx/darwin compatible.
+**vem** that is an interactive tool with some nice features to manage standard
+virtual environment and it is osx/darwin compatible.
 """
 import os
 import sys
@@ -21,7 +23,7 @@ import gzip
 import shutil
 
 
-__version__ = '1.0.8'
+__version__ = '1.0.10'
 
 
 def fake_setup(**kwargs):
@@ -29,11 +31,11 @@ def fake_setup(**kwargs):
 
 
 def read_setup():
-    setup_info = os.path.abspath(
-        os.path.join(os.path.dirname(__file__), 'setup.info'))
+    setup_info = os.path.abspath(os.path.join(os.path.dirname(__file__), 'setup.info'))
     if not os.path.isfile(setup_info):
         setup_info = os.path.abspath(
-            os.path.join(os.path.dirname(__file__), '..', 'setup.py'))
+            os.path.join(os.path.dirname(__file__), '..', 'setup.py')
+        )
     setup_args = {}
     if os.path.isfile(setup_info):
         with open(setup_info, 'r') as fd:
@@ -53,8 +55,7 @@ def read_setup():
 
 def get_pypi_paths():
     local_venv = '/devel/venv/'
-    pkgpath = os.path.abspath(
-        os.path.join(os.path.dirname(__file__), '..'))
+    pkgpath = os.path.abspath(os.path.join(os.path.dirname(__file__), '..'))
     bin_path = lib_path = ''
     path = pkgpath
     while not bin_path and path != '/' and path != os.environ['HOME']:
@@ -66,8 +67,9 @@ def get_pypi_paths():
         for path in sys.path:
             if local_venv in path:
                 bin_path = os.path.join(
-                    path[:path.find(local_venv)],
-                    *[x for x in local_venv.split('/') if x][:-1])
+                    path[: path.find(local_venv)],
+                    *[x for x in local_venv.split('/') if x][:-1]
+                )
                 break
     return pkgpath, bin_path, lib_path
 
@@ -143,17 +145,18 @@ def main(cli_args=None):
             verbose = True
     setup_args = read_setup()
     if action == '-h':
-        print('%s [-h][-H][--help][-V][--version][-C][--copy-pkg-data]' %
-              setup_args['name'])
+        print(
+            '%s [-h][-H][--help][-V][--version][-C][--copy-pkg-data]'
+            % setup_args['name']
+        )
     elif action in ('-V', '--version'):
         if setup_args['version'] == __version__:
             print(setup_args['version'])
         else:
-            print('Version mismatch %s/%s' % (setup_args['version'],
-                                              __version__))
+            print('Version mismatch %s/%s' % (setup_args['version'], __version__))
     elif action in ('-H', '--help'):
         for text in __doc__.split('\n'):
             print(text)
     elif action in ('-C', '--copy-pkg-data'):
         copy_pkg_data(setup_args, verbose)
-    return 0
\ No newline at end of file
+    return 0
